import { basename } from '../../util/path.js';
import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
import { toEntryPattern, toProductionEntryPattern } from '../../util/protocols.js';
const NAME = '';
const ENABLERS = [''];
const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
const CONFIG_FILE_PATTERNS = [];
const ENTRY_FILE_PATTERNS = [];
const PRODUCTION_ENTRY_FILE_PATTERNS = [];
const PROJECT_FILE_PATTERNS = [];
const findPluginDependencies = async (configFilePath, options) => {
    const { manifest, config, isProduction } = options;
    const localConfig = basename(configFilePath) === 'package.json' ? manifest.plugin : await load(configFilePath);
    if (!localConfig)
        return [];
    const entryPatterns = (config?.entry ?? localConfig.entryPathsOrPatterns ?? ENTRY_FILE_PATTERNS).map(toEntryPattern);
    const productionPatterns = config.entry ? [] : PRODUCTION_ENTRY_FILE_PATTERNS.map(toProductionEntryPattern);
    if (isProduction)
        return [...entryPatterns, ...productionPatterns];
    const dependencies = localConfig?.plugins ?? [];
    return [...dependencies, ...entryPatterns, ...productionPatterns];
};
const findDependencies = timerify(findPluginDependencies);
export default {
    NAME,
    ENABLERS,
    isEnabled,
    CONFIG_FILE_PATTERNS,
    ENTRY_FILE_PATTERNS,
    PRODUCTION_ENTRY_FILE_PATTERNS,
    PROJECT_FILE_PATTERNS,
    findDependencies,
};
