import { timerify } from '../../util/Performance.js';
import { hasDependency } from '../../util/plugin.js';
import { toEntryPattern, toProductionEntryPattern } from '../../util/protocols.js';
const NAME = 'Remix';
const ENABLERS = [/^@remix-run\//];
const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
const ENTRY_FILE_PATTERNS = ['remix.config.js', 'remix.init/index.js'];
const PRODUCTION_ENTRY_FILE_PATTERNS = [
    'app/root.tsx',
    'app/entry.{client,server}.{js,jsx,ts,tsx}',
    'app/routes/**/*.{js,ts,tsx}',
    'server.{js,ts}',
];
const findRemixDependencies = async (configFilePath, options) => {
    const { config } = options;
    return config.entry
        ? config.entry.map(toProductionEntryPattern)
        : [...ENTRY_FILE_PATTERNS.map(toEntryPattern), ...PRODUCTION_ENTRY_FILE_PATTERNS.map(toProductionEntryPattern)];
};
const findDependencies = timerify(findRemixDependencies);
export default {
    NAME,
    ENABLERS,
    isEnabled,
    ENTRY_FILE_PATTERNS,
    PRODUCTION_ENTRY_FILE_PATTERNS,
    findDependencies,
};
