import { basename, isInternal } from '../../util/path.js';
import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
const NAME = 'Stylelint';
const ENABLERS = ['stylelint'];
const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
const CONFIG_FILE_PATTERNS = ['.stylelintrc', '.stylelintrc.{cjs,js,json,yaml,yml}', 'stylelint.config.{cjs,mjs,js}'];
const findDependenciesInConfig = (config) => {
    const extend = config.extends ? [config.extends].flat().filter(id => !isInternal(id)) : [];
    const plugins = config.plugins ? [config.plugins].flat().filter(id => !isInternal(id)) : [];
    const overrideConfigs = 'overrides' in config ? config.overrides.flatMap(findDependenciesInConfig) : [];
    return [...extend, ...plugins, ...overrideConfigs];
};
const findPluginDependencies = async (configFilePath, options) => {
    const { manifest, isProduction } = options;
    if (isProduction)
        return [];
    const localConfig = basename(configFilePath) === 'package.json' ? manifest.stylelint : await load(configFilePath);
    if (!localConfig)
        return [];
    return findDependenciesInConfig(localConfig);
};
const findDependencies = timerify(findPluginDependencies);
export default {
    NAME,
    ENABLERS,
    isEnabled,
    CONFIG_FILE_PATTERNS,
    findDependencies,
};
